@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.017-9-g9c24e71
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.018-8-g0a19d4a
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use Moose;
 with
@@ -21,7 +21,6 @@ use Try::Tiny;
 use Path::Tiny;
 use File::ShareDir;
 use namespace::autoclean;
-use feature 'state';
 use Term::ANSIColor 3.00 'colored';
 
 has raw => (
@@ -114,6 +113,9 @@ sub after_build
         if first { $_->name eq 'Build.PL' } @{ $self->zilla->files };
 }
 
+# track which subs have already been included by some other instance
+my %included_subs;
+
 sub setup_installer
 {
     my $self = shift;
@@ -153,9 +155,6 @@ sub setup_installer
 
     $content =~ s/\n+\z/\n/;
 
-    # track which subs have already been included by some other instance
-    state %included_subs;
-
     if (my @include_subs = grep { not exists $included_subs{$_} } $self->_all_required_subs)
     {
         $content .= "\n# inserted by " . blessed($self) . ' ' . $self->VERSION
@@ -314,7 +313,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -621,6 +620,12 @@ I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 Karen Etheridge <ether@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Graham Ollis
+
+Graham Ollis <perl@wdlabs.com>
+
 =head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
